.. Firmant documentation master file, created by
   sphinx-quickstart on Sun Feb 14 23:48:10 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Firmant's documentation!
===================================

.. include:: README.rst

.. automodule:: firmant

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
